==> antlr4-editor-1.0.24.tgz: package/docs/interfaces/_decoration_token_decoration_.tokendecoration.md <==
[antlr4-editor](../README.md) > ["decoration/token-decoration"](../modules/_decoration_token_decoration_.md) > [TokenDecoration](../interfaces/_decoration_token_decoration_.tokendecoration.md)

# Interface: TokenDecoration

## Hierarchy

**TokenDecoration**

## Implemented by

* [CodeMirrorTokenDecoration](../classes/_implementions_codemirror_decoration_codemirror_token_decoration_.codemirrortokendecoration.md)

## Index

### Properties

* [clearOnEnter](_decoration_token_decoration_.tokendecoration.md#clearonenter)
* [toggleOnExit](_decoration_token_decoration_.tokendecoration.md#toggleonexit)

### Methods

* [getDomElement](_decoration_token_decoration_.tokendecoration.md#getdomelement)
* [getToken](_decoration_token_decoration_.tokendecoration.md#gettoken)
* [hide](_decoration_token_decoration_.tokendecoration.md#hide)
* [isHidden](_decoration_token_decoration_.tokendecoration.md#ishidden)
* [remove](_decoration_token_decoration_.tokendecoration.md#remove)
* [show](_decoration_token_decoration_.tokendecoration.md#show)

---

## Properties

<a id="clearonenter"></a>

###  clearOnEnter

**● clearOnEnter**: *`boolean`*

___
<a id="toggleonexit"></a>

###  toggleOnExit

**● toggleOnExit**: *`boolean`*

___

## Methods

<a id="getdomelement"></a>

###  getDomElement

▸ **getDomElement**(): `HTMLElement`

**Returns:** `HTMLElement`

___
<a id="gettoken"></a>

###  getToken

▸ **getToken**(): `AntlrTokenWrapper`

**Returns:** `AntlrTokenWrapper`

___
<a id="hide"></a>

###  hide

▸ **hide**(): `void`

**Returns:** `void`

___
<a id="ishidden"></a>

###  isHidden

▸ **isHidden**(): `boolean`

**Returns:** `boolean`

___
<a id="remove"></a>

###  remove

▸ **remove**(): `void`

**Returns:** `void`

___
<a id="show"></a>

###  show

▸ **show**(): `void`

**Returns:** `void`

___

==> antlr4-editor-1.0.63.tgz: package/docs/interfaces/_decoration_token_decoration_.tokendecoration.md <==
[antlr4-editor](../README.md) > ["decoration/token-decoration"](../modules/_decoration_token_decoration_.md) > [TokenDecoration](../interfaces/_decoration_token_decoration_.tokendecoration.md)

# Interface: TokenDecoration

## Hierarchy

**TokenDecoration**

## Implemented by

* [CodeMirrorTokenDecoration](../classes/_implementations_codemirror_decoration_codemirror_token_decoration_.codemirrortokendecoration.md)

## Index

### Properties

* [clearOnEnter](_decoration_token_decoration_.tokendecoration.md#clearonenter)
* [toggleOnExit](_decoration_token_decoration_.tokendecoration.md#toggleonexit)

### Methods

* [getDomElement](_decoration_token_decoration_.tokendecoration.md#getdomelement)
* [getToken](_decoration_token_decoration_.tokendecoration.md#gettoken)
* [hide](_decoration_token_decoration_.tokendecoration.md#hide)
* [isHidden](_decoration_token_decoration_.tokendecoration.md#ishidden)
* [remove](_decoration_token_decoration_.tokendecoration.md#remove)
* [show](_decoration_token_decoration_.tokendecoration.md#show)

---

## Properties

<a id="clearonenter"></a>

###  clearOnEnter

**● clearOnEnter**: *`boolean`*

___
<a id="toggleonexit"></a>

###  toggleOnExit

**● toggleOnExit**: *`boolean`*

___

## Methods

<a id="getdomelement"></a>

###  getDomElement

▸ **getDomElement**(): `HTMLElement`

**Returns:** `HTMLElement`

___
<a id="gettoken"></a>

###  getToken

▸ **getToken**(): `AntlrTokenWrapper`

**Returns:** `AntlrTokenWrapper`

___
<a id="hide"></a>

###  hide

▸ **hide**(): `void`

**Returns:** `void`

___
<a id="ishidden"></a>

###  isHidden

▸ **isHidden**(): `boolean`

**Returns:** `boolean`

___
<a id="remove"></a>

###  remove

▸ **remove**(): `void`

**Returns:** `void`

___
<a id="show"></a>

###  show

▸ **show**(): `void`

**Returns:** `void`

___
